function log = buildr48()

% Load model
HA = build_ha48();

% options
dim = 49;
options.R0 = zonotope(interval([0.0002;0.0002;0.0002;0.0002;0.0002;...
                                0.0002;0.0002;0.0002;0.0002;0.0002;...
                                0;0;0;0;0;...
                                0;0;0;0;0;...
                                0;0;0;0;-0.0001;...
                                0;0;0;0;0;...
                                0;0;0;0;0;...
                                0;0;0;0;0;...
                                0;0;0;0;0;...
                                0;0;0;0],...
                               [0.00025;0.00025;0.00025;0.00025;0.00025;...
                               0.00025;0.00025;0.00025;0.00025;0.00025;...
                               0;0;0;0;0;...
                               0;0;0;0;0;...
                               0;0;0;0;0.0001;...
                               0;0;0;0;0;...
                               0;0;0;0;0;...
                               0;0;0;0;0;...
                               0;0;0;0;0;...
                               0;0;0;0]));
options.x0 = center(options.R0); %initial state for simulation
options.startLoc = 1; %initial location
options.finalLoc = 0; %0: no final location
options.tStart = 0; %start time
options.tFinal = 20; %final time
options.timeStepLoc{1} = 0.005; %time step size for reachable set computation

options.taylorTerms = 4;
options.zonotopeOrder = 50;
options.polytopeOrder = 1;

options.errorOrder=1.2;
%options.maxProjectionError=inf;

options.reductionTechnique = 'girard';
options.isHyperplaneMap = 0;
options.enclosureEnables = [3,5];
options.originContained = 0;

options.guardIntersect = 'zonoGirard';

%set input:
% options.uLoc{1} = interval([0.8], [1]); % Original: u1 >= 0.8000000 & u1 <= 1.0000000
% options.uLocTrans{1} = options.uLoc{1};
% options.Uloc{1} = zonotope(0);

options.uLoc{1} = 0;
options.uLocTrans{1} = 0;
options.Uloc{1} = zonotope([0.9,0.1]);


% uTrans=0.9;
% options.uTrans=uTrans; %center of input set
% options.U=zonotope([options.uTrans,0.1]); %input for reachability analysis


sim = 0;
reacha = 1;
vis = 1;

% Simulation --------------------------------------------------------------

if sim
    N = 50;
    tic;
    for i=1:N
        %set initial state, input
        if i == 1
            %simulate center
            options.x0 = center(options.R0);
        elseif i < 5
            % simulate extreme points
            options.x0 = randPointExtreme(options.R0);
        else
            % simulate random points
            options.x0 = randPoint(options.R0);
        end 

        %simulate hybrid automaton
        HAsim = simulate(HA,options);
        simRes{i} = get(HAsim,'trajectory');
    end
    toc;
    disp(['Time needed for the simulation: ', num2str(toc)]);

    % Visualization -------------------------------------------------------
    figure 
    hold on
    box on
    options.projectedDimensions = [dim 1];
    options.plotType = {'b','m','g'};
    plotFilled(options.R0,options.projectedDimensions,'w','EdgeColor','k'); %plot initial set
    for i = 1:length(simRes)
       for j = 1:length(simRes{i}.x)
           plot(simRes{i}.x{j}(:,options.projectedDimensions(1)), ...
                simRes{i}.x{j}(:,options.projectedDimensions(2)),'k'); 
       end
    end
    xlabel('t');
    ylabel('x1');
end

% Reachability ------------------------------------------------------------
if reacha
    disp("Starting reachability analysis.");
    tic;
    [HA] = reach(HA,options);
    reachabilityT = toc;
    disp("Finished reachability analysis.");
    
    % Verification --------------------------------------------------------
    
    Rset = get(HA, 'reachableSet');
    Rset = Rset.OT;
    
    disp("Starting verification.");
    
        tic
violation = 0;
boundReached1 = 0;

for i=1:length(Rset{1,1})
    x_25 = interval(project(Rset{1,1}{i},25));
    if supremum(x_25) > 5.1e-3
        violation = 1;
    end
    if supremum(x_25) > 4e-3
        boundReached1 = 1;
    end
end

violation
boundReached1

verificationT = toc;
disp(['computation time of verification: ',num2str(verificationT)]);
    

    time = reachabilityT + verificationT;

    disp(time);

    
% Visualization -------------------------------------------------------
if vis  
    fig = figure(); 
    hold on
    options.projectedDimensions = [dim 25];

    options.plotType = 'b';
    plot(HA,'reachableSet',options); %plot reachable set
    plotFilled(options.R0,options.projectedDimensions,'w','EdgeColor','k'); %plot initial set
    xlabel('t');
    ylabel('x25');
    
end
end
end